@@ -81,6 +81,7 @@ from .custom import DateTime
 from .date_time_union import DateTimeUnion
 from .dice import Dice
 from .direct_message_price_changed import DirectMessagePriceChanged
+from .direct_messages_topic import DirectMessagesTopic
 from .document import Document
 from .downloadable import Downloadable
 from .encrypted_credentials import EncryptedCredentials
@@ -99,6 +100,7 @@ from .game_high_score import GameHighScore
 from .general_forum_topic_hidden import GeneralForumTopicHidden
 from .general_forum_topic_unhidden import GeneralForumTopicUnhidden
 from .gift import Gift
+from .gift_background import GiftBackground
 from .gift_info import GiftInfo
 from .gifts import Gifts
 from .giveaway import Giveaway
@@ -273,6 +275,14 @@ from .story_area_type_union import StoryAreaTypeUnion
 from .story_area_type_unique_gift import StoryAreaTypeUniqueGift
 from .story_area_type_weather import StoryAreaTypeWeather
 from .successful_payment import SuccessfulPayment
+from .suggested_post_approval_failed import SuggestedPostApprovalFailed
+from .suggested_post_approved import SuggestedPostApproved
+from .suggested_post_declined import SuggestedPostDeclined
+from .suggested_post_info import SuggestedPostInfo
+from .suggested_post_paid import SuggestedPostPaid
+from .suggested_post_parameters import SuggestedPostParameters
+from .suggested_post_price import SuggestedPostPrice
+from .suggested_post_refunded import SuggestedPostRefunded
 from .switch_inline_query_chosen_chat import SwitchInlineQueryChosenChat
 from .text_quote import TextQuote
 from .transaction_partner import TransactionPartner
@@ -287,6 +297,7 @@ from .transaction_partner_user import TransactionPartnerUser
 from .unique_gift import UniqueGift
 from .unique_gift_backdrop import UniqueGiftBackdrop
 from .unique_gift_backdrop_colors import UniqueGiftBackdropColors
+from .unique_gift_colors import UniqueGiftColors
 from .unique_gift_info import UniqueGiftInfo
 from .unique_gift_model import UniqueGiftModel
 from .unique_gift_symbol import UniqueGiftSymbol
@@ -294,6 +305,7 @@ from .update import Update
 from .user import User
 from .user_chat_boosts import UserChatBoosts
 from .user_profile_photos import UserProfilePhotos
+from .user_rating import UserRating
 from .user_shared import UserShared
 from .users_shared import UsersShared
 from .venue import Venue
@@ -390,6 +402,7 @@ __all__ = (
     "DateTimeUnion",
     "Dice",
     "DirectMessagePriceChanged",
+    "DirectMessagesTopic",
     "Document",
     "Downloadable",
     "EncryptedCredentials",
@@ -409,6 +422,7 @@ __all__ = (
     "GeneralForumTopicHidden",
     "GeneralForumTopicUnhidden",
     "Gift",
+    "GiftBackground",
     "GiftInfo",
     "Gifts",
     "Giveaway",
@@ -581,6 +595,14 @@ __all__ = (
     "StoryAreaTypeUniqueGift",
     "StoryAreaTypeWeather",
     "SuccessfulPayment",
+    "SuggestedPostApprovalFailed",
+    "SuggestedPostApproved",
+    "SuggestedPostDeclined",
+    "SuggestedPostInfo",
+    "SuggestedPostPaid",
+    "SuggestedPostParameters",
+    "SuggestedPostPrice",
+    "SuggestedPostRefunded",
     "SwitchInlineQueryChosenChat",
     "TelegramObject",
     "TextQuote",
@@ -598,6 +620,7 @@ __all__ = (
     "UniqueGift",
     "UniqueGiftBackdrop",
     "UniqueGiftBackdropColors",
+    "UniqueGiftColors",
     "UniqueGiftInfo",
     "UniqueGiftModel",
     "UniqueGiftSymbol",
@@ -605,6 +628,7 @@ __all__ = (
     "User",
     "UserChatBoosts",
     "UserProfilePhotos",
+    "UserRating",
     "UserShared",
     "UsersShared",
     "Venue",
